@@ -22,8 +22,7 @@ def TANK(imgA,imgB):
                 #print(gray)
                 i.putpixel((w,h),(gray,gray,gray,a))
             except:
-                print("Something wrong")
-                raise ValueError
+                pass
             
     return i
 
@@ -39,7 +38,7 @@ def make(imgOuter,imgInner,output):
     a2 = np.array(imgInner)
     img2 = img.fromarray(a2//2)
     #img2.show()
-    
+
     OutputImg = TANK(img1,img2)
     OutputImg.save(output)
     print(f'Mirage tank saved as {output}')
